#############
API interface
#############

Here we document the various classes, functions and modules provided within CWInPy.

Handling heterodyned data
=========================

.. toctree::
   :maxdepth: 2

   data

Bayesian inference
==================

.. toctree::
   :maxdepth: 2

   Likelihood function <likelihood>
   Hierarchical inference <hierarchical>

Plotting
========

.. toctree::
   :maxdepth: 2

   plotting

Signal simulation
=================

.. toctree::
   :maxdepth: 2

   Simulating an individual signal <signal>
   Simulating a population of signals <simulation>

Observing run information
=========================

.. toctree::
   :maxdepth: 2

   information

Utility functions
=================

.. toctree::
   :maxdepth: 2

   utils
   parfile